@@ -1,12 +1,12 @@
 
 /*
- *  $Id: defLex.c,v 4.7 2005/07/27 17:26:31 bkorb Exp $
+ *  $Id: defLex.c,v 4.12 2006/03/25 19:24:49 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -169,7 +169,7 @@ scanAgain:
             return DP_EV_INVALID;
         }
 
-        lastToken = DP_EV_STRING;
+        lastToken = DP_EV_HERE_STRING;
         pCurCtx->pzScan = pz;
         break;
     }
@@ -216,7 +216,7 @@ scanAgain:
         pCurCtx->pzScan = pz;
 
         if (pzShellProgram == NULL)
-            pzShellProgram = getDefine( zShellEnv );
+            pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
         lastToken = DP_EV_STRING;
         pz = runShell( (const char*)pz_token );
@@ -224,6 +224,7 @@ scanAgain:
             goto scanAgain;
         TAGMEM( pz, "shell definition string" );
         pz_token = pz;
+        manageAllocatedData( pz );
         break;
     }
 
@@ -357,6 +358,7 @@ loadScheme( void )
         AGDUPSTR( pzEnd, pzEnd, "SCM Result" );
 
         pz_token = pzEnd;
+        manageAllocatedData( pz_token );
     }
 
     else {
@@ -408,12 +410,12 @@ alist_to_autogen_def( void )
     /*
      *  The result *must* be a string, or we choke.
      */
-    if (! gh_string_p( res )) {
+    if (! AG_SCM_STRING_P( res )) {
         tSCC zEr[] = "Scheme definition expression does not yield string:\n";
         AG_ABEND( zEr );
     }
 
-    res_len   = SCM_LENGTH( res );
+    res_len   = AG_SCM_STRLEN( res );
     procState = PROC_STATE_LOAD_DEFS;
     pCurCtx->pzScan = pzEnd;
     AGFREE( (void*)pzText );
@@ -433,7 +435,7 @@ alist_to_autogen_def( void )
     pCtx->pzScan = \
     pCtx->pzData = (char*)(pCtx+1);
     pCtx->lineNo = 0;
-    memcpy( (void*)(pCtx->pzScan), (void*)SCM_CHARS( res ), res_len );
+    memcpy( (void*)(pCtx->pzScan), (void*)AG_SCM_CHARS( res ), res_len );
     pCtx->pzScan[ res_len ] = NUL;
 
     /*
