@@ -1,12 +1,12 @@
 /*
- *  $Id: defLoad.c,v 4.8 2005/12/04 22:26:21 bkorb Exp $
+ *  $Id: defLoad.c,v 4.10 2006/03/25 19:24:49 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -39,6 +39,40 @@ static tDefEntry*
 insertDef( tDefEntry* pDef );
 /* = = = END-STATIC-FORWARD = = = */
 
+#if defined(DEBUG_ENABLED)
+void
+manageAllocatedData( void* pd )
+{
+    static int    allocPtrCt   = 0;
+    static int    usedPtrCt    = 0;
+    static void** papAllocData = NULL;
+
+    if (pd == NULL) {
+        void** pp = papAllocData;
+        if (pp == NULL)
+            return;
+
+        while (--usedPtrCt >= 0)
+            AGFREE(*(pp++));
+
+        AGFREE(papAllocData);
+        papAllocData = NULL;
+
+    } else {
+        if (++usedPtrCt > allocPtrCt) {
+            allocPtrCt += 16;
+            papAllocData = (usedPtrCt > 1)
+                ? AGREALOC( papAllocData, allocPtrCt * sizeof(void*),
+                            "alloc table" )
+                : AGALOC( allocPtrCt * sizeof(void*), "new alloc table" );
+            if (papAllocData == NULL)
+                AG_ABEND( "failed alloc of papAllocData" );
+        }
+        papAllocData[usedPtrCt-1] = pd;
+    }
+}
+#endif
+
 LOCAL void
 freeEntry( tDefEntry* pDE )
 {
@@ -59,6 +93,8 @@ getEntry( void )
         int   ct = ENTRY_ALLOC_CT-1;
         void* p  = AGALOC( ENTRY_ALLOC_SIZE, "definition headers" );
 
+        manageAllocatedData(p);
+
         *((void**)p) = pAllocList;
         pAllocList   = p;
         pRes = pFreeEntryList = (tDefEntry*)((void**)p + 1);
@@ -244,6 +280,7 @@ findPlace( char* name, tCC* pzIndex )
 LOCAL void
 readDefines( void )
 {
+    tCC*     pzDefFile;
     char*    pzData;
     size_t   dataSize;
     size_t   sizeLeft;
@@ -255,17 +292,20 @@ readDefines( void )
         memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
         pBaseCtx->lineNo     = 1;
         pBaseCtx->pzCtxFname = "@@ No-Definitions @@";
+        manageAllocatedData( pBaseCtx );
         return;
     }
 
+    pzDefFile = OPT_ARG( DEFINITIONS );
+
     /*
      *  Check for stdin as the input file.  We use the current time
      *  as the modification time for stdin.  We also note it so we
      *  do not try to open it and we try to allocate more memory if
      *  the stdin input exceeds our initial allocation of 16K.
      */
-    if (strcmp( OPT_ARG( DEFINITIONS ), "-" ) == 0) {
-        OPT_ARG( DEFINITIONS ) = "stdin";
+    if (strcmp( pzDefFile, "-" ) == 0) {
+        pzDefFile = OPT_ARG( DEFINITIONS ) = "stdin";
         if (getenv( "REQUEST_METHOD" ) != NULL) {
             loadCgi();
             pCurCtx = pBaseCtx;
@@ -285,14 +325,14 @@ readDefines( void )
     else {
         struct stat stbf;
 
-        if (stat( OPT_ARG( DEFINITIONS ), &stbf ) != 0)
-            AG_ABEND( aprf( zCannot, errno, "stat", OPT_ARG( DEFINITIONS ),
-                            strerror( errno )));
+        if (stat( pzDefFile, &stbf ) != 0)
+            AG_ABEND( aprf( zCannot, errno, "stat",
+                            pzDefFile, strerror( errno )));
 
         if (! S_ISREG( stbf.st_mode )) {
             errno = EINVAL;
             AG_ABEND( aprf( zCannot, errno, "open non-regular file",
-                            OPT_ARG( DEFINITIONS ), strerror( errno )));
+                            pzDefFile, strerror( errno )));
         }
 
         /*
@@ -336,10 +376,10 @@ readDefines( void )
     if (useStdin)
         fp = stdin;
     else {
-        fp = fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
+        fp = fopen( pzDefFile, "r" FOPEN_TEXT_FLAG );
         if (fp == NULL)
-            AG_ABEND( aprf( zCannot, errno, "open", OPT_ARG( DEFINITIONS ),
-                            strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "open",
+                            pzDefFile, strerror( errno )));
     }
 
     /*
@@ -359,8 +399,8 @@ readDefines( void )
             if (feof( fp ) || useStdin)
                 break;
 
-            AG_ABEND( aprf( zCannot, errno, "read", OPT_ARG( DEFINITIONS ),
-                            strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "read",
+                            pzDefFile, strerror( errno )));
         }
 
         /*
@@ -408,7 +448,9 @@ readDefines( void )
         AG_ABEND( "No definition data were read" );
 
     *pzData = NUL;
-    AGDUPSTR( pBaseCtx->pzCtxFname, OPT_ARG( DEFINITIONS ), "def file name" );
+    AGDUPSTR( pBaseCtx->pzCtxFname, pzDefFile, "def file name" );
+    manageAllocatedData( pBaseCtx );
+    manageAllocatedData( (void*)pBaseCtx->pzCtxFname );
 
     /*
      *  Close the input file, parse the data
@@ -422,9 +464,10 @@ readDefines( void )
 }
 
 
-void
+LOCAL void
 unloadDefs( void )
 {
+    return;
 }
 /*
  * Local Variables:
