@@ -2,12 +2,12 @@
 /*  -*- Mode: C -*-
  *
  *  expMake.c
- *  $Id: expMake.c,v 4.2 2005/01/24 00:00:32 bkorb Exp $
+ *  $Id: expMake.c,v 4.5 2006/03/25 19:24:49 bkorb Exp $
  *  This module implements Makefile construction functions.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -22,8 +22,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 /*=gfunc makefile_script
@@ -117,7 +117,7 @@ ag_scm_makefile_script( SCM text )
     }
 
     if (*pzText == NUL)
-        return gh_str02scm( "" );
+        return AG_SCM_STR02SCM( "" );
 
     {
         char*  pz  = strchr( pzText, '\n' );
@@ -255,11 +255,7 @@ ag_scm_makefile_script( SCM text )
         } copy_done:;
 
         sz    = (pzOut - pzRes);
-        res   = scm_makstr( sz, 0 );
-        pzOut = SCM_CHARS( res );
-
-        memcpy( pzOut, pzRes, sz );
-
+        res   = AG_SCM_STR2SCM( pzRes, sz );
         AGFREE( pzRes );
     }
 
