@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcEval.c,v 4.4 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: funcEval.c,v 4.7 2006/03/25 19:24:49 bkorb Exp $
  *
  *  This module evaluates macro expressions.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -174,7 +174,7 @@ evalExpression( ag_bool* pMustFree )
 
             if (  (pDef->valType != VALTYP_TEXT)
                && ((code & EMIT_PRIMARY_TYPE) == EMIT_VALUE)  ) {
-                fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
+                fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
                          zBlock );
                 return (char*)zDefaultNil;
             }
@@ -195,7 +195,7 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
+                    fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
                              zBlock );
                     return (char*)zDefaultNil;
                 }
@@ -212,7 +212,7 @@ evalExpression( ag_bool* pMustFree )
                  *  And make sure what we found is a text value
                  */
                 if (pDef->valType != VALTYP_TEXT) {
-                    fprintf( pfTrace, zTplWarn, pT->pzFileName, pMac->lineNo,
+                    fprintf( pfTrace, zTplWarn, pT->pzTplFile, pMac->lineNo,
                              zBlock );
                     return (char*)zDefaultNil;
                 }
@@ -292,6 +292,7 @@ ag_scm_error_source_line( void )
     fprintf( stderr, zErr, pCurTemplate->pzTplName, pCurMacro->lineNo,
              pCurTemplate->pzTemplText + pCurMacro->ozText );
     fflush( stderr );
+    guileFailure = 1;
 
     return SCM_UNDEFINED;
 }
@@ -317,7 +318,7 @@ ag_scm_emit( SCM val )
         if (SCM_NULLP( val ))
             break;
 
-        if (gh_string_p( val )) {
+        if (AG_SCM_STRING_P( val )) {
             fputs( (char*)ag_scm2zchars( val, "emit val" ), pCurFp->pFile );
             fflush( pCurFp->pFile );
             break;
@@ -372,7 +373,7 @@ eval( const char* pzExpr )
         (void)spanQuote( pzTemp );
         pzExpr = runShell( pzTemp );
         AGFREE( (void*)pzTemp );
-        res = gh_str02scm( (char*)pzExpr );
+        res = AG_SCM_STR02SCM( (char*)pzExpr );
         AGFREE( (void*)pzExpr );
         break;
 
@@ -385,7 +386,7 @@ eval( const char* pzExpr )
         /* FALLTHROUGH */
 
     default:
-        res = gh_str02scm( (char*)pzExpr );
+        res = AG_SCM_STR02SCM( (char*)pzExpr );
         if (allocated)
             AGFREE( (void*)pzExpr );
     }
@@ -397,7 +398,10 @@ eval( const char* pzExpr )
 /*=macfunc EXPR
  *
  *  what:  Evaluate and emit an Expression
- *  alias: + - + ? + % + ; + ( + . + '`' + '"' + "'" +
+ *  alias: + - + ? + % + ; + ( + '`' + '"' + "'" + . +
+ *
+ *  handler_proc:
+ *  load_proc:
  *
  *  desc:
  *   This macro does not have a name to cause it to be invoked
