@@ -1,10 +1,10 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Jan  8 19:27:20 PST 2006
+ * Generated Sun Apr  9 11:49:58 PDT 2006
  */
 #ifndef AGEN5_PROTO_H_GUARD
-#define AGEN5_PROTO_H_GUARD
+#define AGEN5_PROTO_H_GUARD 1
 #ifndef LOCAL
 #  define LOCAL extern
 #  define REDEF_LOCAL 1
@@ -116,6 +116,9 @@ findPlace( char* name, tCC* pzIndex );
 LOCAL void
 readDefines( void );
 
+LOCAL void
+unloadDefs( void );
+
 /*
  *  Extracted from expGuile.c
  */
@@ -173,12 +176,15 @@ findTemplate( tCC* pzTemplName );
 LOCAL tSuccess
 findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
 
-LOCAL tTemplate*
-templateFixup( tTemplate* pTList, size_t ttlSize );
-
 LOCAL tTemplate*
 loadTemplate( tCC* pzFileName );
 
+LOCAL void
+unloadTemplate( tTemplate* pT );
+
+LOCAL void
+cleanup( tTemplate* pTF );
+
 /*
  *  Extracted from tpParse.c
  */
