@@ -1,12 +1,12 @@
 
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.5 2005/12/04 22:26:21 bkorb Exp $
+ *  $Id: tpProcess.c,v 4.7 2006/03/25 19:24:49 bkorb Exp $
  *  Parse and process the template data descriptions
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -64,7 +64,7 @@ generateBlock( tTemplate*   pT,
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
 
             fprintf( pfTrace, zFmt, apzFuncNames[ fc ], pMac->funcCode,
-                     pT->pzFileName, pMac->lineNo );
+                     pT->pzTplFile, pMac->lineNo );
             if (pMac->ozText > 0) {
                 int   ct;
                 char* pz = pT->pzTemplText + pMac->ozText;
