@@ -1,6 +1,7 @@
 
 /*
- *  restore.c  $Id: restore.c,v 2.11 2004/02/02 03:31:51 bkorb Exp $
+ *  restore.c  $Id: restore.c,v 4.6 2006/03/25 19:24:56 bkorb Exp $
+ * Time-stamp:      "2005-02-23 15:10:20 bkorb"
  *
  *  This module's routines will save the current option state to memory
  *  and restore it.  If saved prior to the initial optionProcess call,
@@ -8,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -23,8 +24,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -50,9 +51,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-/* === STATIC PROCS === */
-/* === END STATIC PROCS === */
-
 /*=export_func optionSaveState
  *
  * what:  saves the option state to memory
@@ -89,9 +87,33 @@ optionSaveState( tOptions* pOpts )
     }
 
     {
-        tOptions* p = pOpts->pSavedState;
+        tOptions* p   = pOpts->pSavedState;
+        tOptDesc* pOD = pOpts->pOptDesc;
+        int       ct  = pOpts->optCt;
+
         memcpy( p, pOpts, sizeof( *p ));
         memcpy( p + 1, pOpts->pOptDesc, p->optCt * sizeof( tOptDesc ));
+
+        /*
+         *  Make sure that allocated stuff is only referenced in the
+         *  archived copy of the data.
+         */
+        for (; ct-- > 0; pOD++)  {
+            switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
+            case OPARG_TYPE_STRING:
+                if (pOD->fOptState & OPTST_STACKED) {
+                    tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
+                    q->optCookie = NULL;
+                }
+                break;
+
+            case OPARG_TYPE_HIERARCHY:
+            {
+                tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
+                q->optCookie = NULL;
+            }
+            }
+        }
     }
 }
 
@@ -141,7 +163,7 @@ optionRestore( tOptions* pOpts )
  *        option state structures.  This routine deallocates all such memory.
  *
  * err:   As long as memory has not been corrupted,
- *        this routine is always successful.      
+ *        this routine is always successful.
 =*/
 void
 optionFree( tOptions* pOpts )
@@ -154,12 +176,24 @@ optionFree( tOptions* pOpts )
         tOptDesc* p = pOpts->pOptDesc;
         int ct = pOpts->optCt;
         do  {
-            if ((p->fOptState & OPTST_STACKED) && (p->optCookie != NULL)) {
-                AGFREE( p->optCookie );
-                p->fOptState &= OPTST_PERSISTENT;
-                if ((p->fOptState & OPTST_INITENABLED) == 0)
-                    p->fOptState |= OPTST_DISABLED;
+            switch (OPTST_GET_ARGTYPE(p->fOptState)) {
+            case OPARG_TYPE_STRING:
+                if (  (p->fOptState & OPTST_STACKED)
+                   && (p->optCookie != NULL)) {
+                    AGFREE( p->optCookie );
+                    p->fOptState &= OPTST_PERSISTENT;
+                    if ((p->fOptState & OPTST_INITENABLED) == 0)
+                        p->fOptState |= OPTST_DISABLED;
+                }
+                break;
+
+            case OPARG_TYPE_HIERARCHY:
+                if (p->optCookie != NULL)
+                    optionUnloadNested(p->optCookie);
+                break;
             }
+
+            p->optCookie = NULL;
         } while (p++, --ct > 0);
     }
 }
