@@ -1,9 +1,23 @@
 /*
- * $Id: text_mmap.c,v 4.8 2005/12/08 17:54:39 bkorb Exp $
+ * $Id: text_mmap.c,v 4.11 2006/02/01 17:18:00 bkorb Exp $
  *
- * Time-stamp:      "2005-12-05 13:40:56 bkorb"
+ * Time-stamp:      "2006-02-01 08:45:37 bkorb"
  */
 
+#ifndef MAP_ANONYMOUS 
+#  ifdef   MAP_ANON 
+#  define  MAP_ANONYMOUS   MAP_ANON 
+#  endif 
+#endif 
+
+/*
+ *  Some weird systems require that a specifically invalid FD number
+ *  get passed in as an argument value.  Which value is that?  Well,
+ *  as everybody knows, if open(2) fails, it returns -1, so that must
+ *  be the value.  :)
+ */
+#define AO_INVALID_FD  -1
+
 #define FILE_WRITABLE(_prt,_flg) \
 	((_prt & PROT_WRITE) && (_flg & (MAP_SHARED|MAP_PRIVATE) == MAP_SHARED))
 #define MAP_FAILED_PTR ((void*)MAP_FAILED)
@@ -114,7 +128,7 @@ text_mmap( const char* pzFile, int prot, int flags, tmap_info_t* pMI )
         pMI->txt_fd = open( pzFile, o_flag );
     }
 
-    if (pMI->txt_fd < 0) {
+    if (pMI->txt_fd == AO_INVALID_FD) {
         pMI->txt_errno = errno;
         return MAP_FAILED_PTR;
     }
@@ -124,7 +138,7 @@ text_mmap( const char* pzFile, int prot, int flags, tmap_info_t* pMI )
      *  do the mmap.  If we fail, then preserve errno, close the file and
      *  return the failure.
      */
-    pMI->txt_data = mmap( NULL, pMI->txt_size, prot, flags, pMI->txt_fd, 0 );
+    pMI->txt_data = mmap( NULL, pMI->txt_size+1, prot, flags, pMI->txt_fd, 0 );
     if (pMI->txt_data == MAP_FAILED_PTR) {
         pMI->txt_errno = errno;
         goto fail_return;
@@ -155,15 +169,15 @@ text_mmap( const char* pzFile, int prot, int flags, tmap_info_t* pMI )
             return pMI->txt_data;
 
         /*
-         *  Still here?  We have to append a page of NUL's
+         *  Still here?  We have to remap the trailing inaccessible page
+         *  either anonymously or to /dev/zero.
          */
         pMI->txt_full_size += pgsz;
 #if defined(MAP_ANONYMOUS)
         pNuls = mmap(
                 (void*)(((char*)pMI->txt_data) + pMI->txt_size),
-                pgsz,
-                PROT_READ|PROT_WRITE,
-                MAP_ANONYMOUS|MAP_FIXED, 0, 0 );
+                pgsz, PROT_READ|PROT_WRITE,
+                MAP_ANONYMOUS|MAP_FIXED|MAP_PRIVATE, AO_INVALID_FD, 0 );
 
         if (pNuls != MAP_FAILED_PTR)
             return pMI->txt_data;
@@ -174,13 +188,14 @@ text_mmap( const char* pzFile, int prot, int flags, tmap_info_t* pMI )
 #if defined(HAVE_DEV_ZERO)
         pMI->txt_zero_fd = open( "/dev/zero", O_RDONLY );
 
-        if (pMI->txt_zero_fd < 0) {
+        if (pMI->txt_zero_fd == AO_INVALID_FD) {
             pMI->txt_errno = errno;
 
         } else {
             pNuls = mmap(
                     (void*)(((char*)pMI->txt_data) + pMI->txt_size), pgsz,
-                    PROT_READ, MAP_PRIVATE|MAP_FIXED, pMI->txt_zero_fd, 0 );
+                    PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_FIXED,
+                    pMI->txt_zero_fd, 0 );
 
             if (pNuls != MAP_FAILED_PTR)
                 return pMI->txt_data;
