@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * As a special exception to the GNU General Public License, if you
  * distribute this file as part of a program that also links with and
@@ -164,7 +164,10 @@ register_printf_function (unsigned spec, printf_function *fmt, printf_arginfo_fu
 }
 
 static int
-call_argtype_function (struct printf_info *const pinfo, int **argtypes, spec_entry *spec)
+call_argtype_function (
+    struct printf_info *const pinfo,
+    int **argtypes,
+    spec_entry *spec)
 {
   int n;
   int argindex = (pinfo->dollar && !IS_MODIFIER (spec))
@@ -216,11 +219,13 @@ call_argtype_function (struct printf_info *const pinfo, int **argtypes, spec_ent
 
       if (n < 0)
 	return n;
-      else if (argindex + n > pinfo->argc)
+      if (argindex + n > pinfo->argc)
         {
-	  *argtypes = snv_renew (int, *argtypes, argindex + n);
+          int new_ct = argindex + n;
+	  *argtypes = snv_renew (int, *argtypes, new_ct);
+          memset(*argtypes + pinfo->argc, PA_UNKNOWN,
+                 (new_ct - pinfo->argc) * sizeof(**argtypes));
 	  pinfo->argc = argindex + n;
-
 	  /* Call again... */
 	  pinfo->argindex = save_argindex;
 	  pinfo->format = save_format;
@@ -258,7 +263,10 @@ printf_strerror (void)
 
 /* (re)initialise the memory used by PPARSER. */
 static inline void
-parser_init (struct printf_info *pinfo, const char *format, const union printf_arg *args)
+parser_init (
+    struct printf_info *pinfo,
+    const char *format,
+    const union printf_arg *args)
 {
   memset (pinfo, 0, sizeof (struct printf_info));
   pinfo->format = format;
@@ -476,7 +484,8 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 	    {
 	      /* We found the start of a format specifier! */
 	      spec_entry *spec;
-	      int status, argindex;
+	      int status;
+	      int argindex;
 
 	      parser_reset (&info);
 	      do
@@ -535,14 +544,13 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 
 	  /*NOBREAK*/
 
-        default:	/* Just a character: ignore it. */
-          /* Just a character: copy it. */
+	default:       /* Just a character: copy it. */
 	  SNV_EMIT (ch, stream, info.count);
 	  continue;
-        }
- 
-    error: 
-      /* Get here on error */ 
+	}
+
+    error:
+      /* Get here on error */
       info.count = -1;
       break;
     }
@@ -583,57 +591,61 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
   return_val_if_fail (format != NULL, SNV_ERROR);
 
   parser_init (&info, format, NULL);
+
+  /* Keep going until the format string runs out! */
   while (*info.format != EOS)
     {
       int ch = (int) *info.format++;
 
       switch (ch)
-       {
-       case SNV_CHAR_SPEC:
-         if (*info.format != SNV_CHAR_SPEC)
-           {
-             /* We found the start of a format specifier! */
-             spec_entry *spec;
+	{
+	case SNV_CHAR_SPEC:
+	  if (*info.format != SNV_CHAR_SPEC)
+	    {
+	      /* We found the start of a format specifier! */
+	      spec_entry *spec;
 
-             parser_reset (&info);
-             do
-               {
-                 /* Until we fill the stream (or get some other
-                    exception) or one of the handlers tells us
-                    we have reached the end of the specifier... */
-                 /* ...lookup the handler associated with the char
-                    we are looking at in the format string... */
-                 spec = spec_lookup (*info.format);
-                 if (spec == NULL)
-                   {
-                     PRINTF_ERROR (&info, "unregistered specifier");
-                     goto error;
-                   }
+	      parser_reset (&info);
+	      do
+		{
+		  /* Until we fill the stream (or get some other
+		     exception) or one of the handlers tells us
+		     we have reached the end of the specifier... */
 
-                 if (!IS_MODIFIER (spec) &&
-                     !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-                   {
-                     PRINTF_ERROR (&info, "invalid combination of flags");
-                     goto error;
-                   }
+		  /* ...lookup the handler associated with the char
+		     we are looking at in the format string... */
+		  spec = spec_lookup (*info.format);
+		  if (spec == NULL)
+		    {
+		      PRINTF_ERROR (&info, "unregistered specifier");
+		      goto error;
+		    }
 
-                 /* ...and call the relevant handler.  */
-                 if (call_argtype_function (&info, &argtypes, spec) < 0)
-                   goto error;
+		  if (!IS_MODIFIER (spec) &&
+		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+		    {
+		      PRINTF_ERROR (&info, "invalid combination of flags");
+		      goto error;
+		    }
 
-                 info.format++;
-               }
-             while (info.count >= 0 && IS_MODIFIER (spec));
-             continue;
-           }
-         /* An escaped CHAR_SPEC: ignore it (by falling through). */
-         ++info.format;
+		  /* ...and call the relevant handler. */
+		  if (call_argtype_function (&info, &argtypes, spec) < 0)
+		    goto error;
 
-         /*NOBREAK*/
+		  info.format++;
+		}
+	      while (info.count >= 0 && IS_MODIFIER (spec));
+	      continue;
+	    }
 
-        default:       /* Just a character: ignore it. */
-         continue;
-       }
+	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
+	  ++info.format;
+
+	  /*NOBREAK*/
+
+	default:       /* Just a character: ignore it. */
+	  continue;
+	}
 
     error:
       /* Get here on error */
@@ -650,67 +662,85 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
       /* We scanned the format string to find the type of the arguments,
          so we can now cast it and store it correctly.  */
       for (index = 0; index < info.argc; index++)
-       switch (argtypes[index] & ~PA_FLAG_UNSIGNED)
-         {
-          case PA_CHAR:
-           args[index].pa_char = (char) *(const long int *)(ap + index);
-            break;
+        {
+          int tp = argtypes[index];
+          if ((tp & PA_TYPE_MASK) == PA_TYPE_MASK)
+            {
+              if (index + 1 == info.argc)
+                {
+                  info.argc--;
+                  break;
+                }
+              continue; /* Ignore it.  We allow skipping args, but the
+                         * user is responsible for ensuring a void* sized
+                         * spacer in the argument list.
+                         */
+            }
 
-          case PA_WCHAR:
-           args[index].pa_wchar = (snv_wchar_t) *(const long int *)(ap + index);
-            break;
+          switch (tp & ~PA_FLAG_UNSIGNED)
+            {
+            case PA_CHAR:
+              args[index].pa_char = (char) *(const long int *)(ap + index);
+              break;
 
-          case PA_INT|PA_FLAG_SHORT:
-           args[index].pa_short_int = (short int) *(const long int *)(ap + index);
-            break;
+            case PA_WCHAR:
+              args[index].pa_wchar =
+                (snv_wchar_t) *(const long int *)(ap + index);
+              break;
 
-          case PA_INT:
-           args[index].pa_int = (int) *(const long int *)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_SHORT:
+              args[index].pa_short_int =
+                (short int) *(const long int *)(ap + index);
+              break;
 
-          case PA_INT|PA_FLAG_LONG:
-           args[index].pa_long_int = *(const long int *)(ap + index);
-            break;
+            case PA_INT:
+              args[index].pa_int = (int) *(const long int *)(ap + index);
+              break;
 
-          case PA_INT|PA_FLAG_LONG_LONG:
-           args[index].pa_long_long_int = **(const intmax_t **)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_LONG:
+              args[index].pa_long_int = *(const long int *)(ap + index);
+              break;
 
-          case PA_FLOAT:
-           args[index].pa_float = **(const float **)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_LONG_LONG:
+              args[index].pa_long_long_int = **(const intmax_t **)(ap + index);
+              break;
 
-          case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
+            case PA_FLOAT:
+              args[index].pa_float = **(const float **)(ap + index);
+              break;
+
+            case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
 #ifdef HAVE_LONG_DOUBLE
-           args[index].pa_long_double = **(const long double **)(ap + index);
-            break;
+              args[index].pa_long_double = **(const long double **)(ap + index);
+              break;
 #endif
-           /* else fall through */
+              /* else fall through */
 
-          case PA_DOUBLE:
-           args[index].pa_double = **(const double **)(ap + index);
-            break;
+            case PA_DOUBLE:
+              args[index].pa_double = **(const double **)(ap + index);
+              break;
 
-         /* Note that pointer types are dereferenced just once! */
-          case PA_STRING:
-           args[index].pa_string = *(const char **)(ap + index);
-            break;
+              /* Note that pointer types are dereferenced just once! */
+            case PA_STRING:
+              args[index].pa_string = *(const char **)(ap + index);
+              break;
 
-          case PA_WSTRING:
-           args[index].pa_wstring = *(const snv_wchar_t **)(ap + index);
-            break;
+            case PA_WSTRING:
+              args[index].pa_wstring = *(const snv_wchar_t **)(ap + index);
+              break;
 
-          case PA_POINTER:
-           args[index].pa_pointer = *(snv_constpointer *)(ap + index);
-            break;
-
-         default:
-            if (argtypes[index] & PA_FLAG_PTR)
+            case PA_POINTER:
               args[index].pa_pointer = *(snv_constpointer *)(ap + index);
-            else
-              args[index].pa_long_double = 0.0;
-            break;
-         }
+              break;
+
+            default:
+              if (argtypes[index] & PA_FLAG_PTR)
+                args[index].pa_pointer = *(snv_constpointer *)(ap + index);
+              else
+                args[index].pa_long_double = 0.0;
+              break;
+            }
+        }
     }
 
   if (printf_last_error)
@@ -804,7 +834,7 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
 
 	  /*NOBREAK*/
 
-        default:	/* Just a character: ignore it. */
+        default: /* Just a character: ignore it. */
 	  continue;
 	}
      
@@ -1503,8 +1533,8 @@ snv_asprintfv (char **result, const char *format, snv_constpointer const args[])
 /*
  * Local Variables:
  * mode: C
- * c-file-style: "stroustrup"
- * tab-width: 4
- * indent-tabs-mode: nil
+ * c-file-style: "gnu"
+ * tab-width: 8
+ * indent-tabs-mode: t
  * End:
  * end of snprintfv/printfv.c */
